@@ -1,6 +1,6 @@
 """A friendly Python Utilitary RPA."""
 
-__version__ = "1.19"
+__version__ = "1.20"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -473,9 +473,11 @@ def config_logging(file_log=None, level=logging.DEBUG, console=True):
     
     if file_log and file_log != "":
         log.addHandler(fh)
+        log.info("Hangler: file")
     
     if console:
         log.addHandler(ch)
+        log.info("Hangler: console")
     
     log.setLevel(level=level)
     
